module SpecTest
  module Matchers

    # Without this matcher, here's what RSpec decides to give you:
    #   expected "Test" to match /^Test App$/
    # With the  matcher, you get this:
    #   Expected that 'Test App' would be the title of the page; found 'Test' instead.
    RSpec::Matchers.define :have_title do |text|
      match do |the_page|
        the_page =~ Regexp.new(text)
      end

      failure_message_for_should do |actual|
        "Expected that '#{text}' would be the title of the page; found '#{actual}' instead."
      end

      failure_message_for_should_not do |actual|
        "Expected that '#{text}' would not be the title of the page; it was, however."
      end

      description do
        "checking for a title of #{text}"
      end
    end

    # Without this matcher, here's what RSpec decides to give you:
    #   expected "Testing with Terminus\nLanding\nStatic Text Examples\nForm Examples\nFrame Examples\nIFrame Examples\nEvent Examples" to match /^Landing Page$/
    # With the  matcher, you get this:
    #   Expected that 'Landing Page' would be in the page content; it was not found.
    RSpec::Matchers.define :contain do |text|
      match do |the_page|
        the_page =~ Regexp.new(text)
      end
      
      failure_message_for_should do |actual|
        "Expected that '#{text}' would be in the page content; it was not found."
      end

      failure_message_for_should_not do |actual|
        "Expected that '#{text}' would not be in the page content; it was, however."
      end

      description do
        "checking for #{text}"
      end
    end
  end
end