module SpecTest
  module WebObjects
    class TextField < WebObject

      def initialize(web_object, platform)
        @web_object = web_object
        mixin_web_objects_for platform
      end

      protected

      def self.locators_for_watir
        super + [:tag_name]
      end

      def self.mappings_for_watir
        super.merge({:css => :tag_name})
      end

      def self.locators_for_selenium
        super + [:css]
      end

      def self.mappings_for_selenium
        super.merge({:tag_name => :css})
      end

      def mixin_web_objects_for(platform)
        super
        if platform[:platform] == :watir_webdriver
          require "spectest/platform_watir/web_objects/text_field"
          self.class.send :include, SpecTest::Platforms::WatirWebDriver::TextField
        elsif platform[:platform] == :selenium_webdriver
          require "spectest/platform_selenium/web_objects/text_field"
          self.class.send :include, SpecTest::Platforms::SeleniumWebDriver::TextField
        else
          raise ArgumentError, "Unable to mixin web objects for the specified platform."
        end
      end

    end # class TextField
  end # module WebObjects
end # module SpecTest